@@ -1,7 +1,6 @@
 #pragma once
 
 #include "IHID.hpp"
-#include "../helpers/WLListener.hpp"
 #include "../macros.hpp"
 #include "../helpers/math/Math.hpp"
 
@@ -43,10 +42,9 @@ class ITouch : public IHID {
         CSignal motion;
         CSignal cancel;
         CSignal frame;
-    } touchEvents;
+    } m_touchEvents;
 
-    std::string hlName      = "";
-    std::string boundOutput = "";
+    std::string m_boundOutput = "";
 
-    WP<ITouch>  self;
+    WP<ITouch>  m_self;
 };
\ No newline at end of file
