@@ -7,4 +7,4 @@ using namespace Hyprutils::Memory;
 
 #define SP Hyprutils::Memory::CSharedPointer
 #define WP Hyprutils::Memory::CWeakPointer
-#define UP std::unique_ptr
+#define UP Hyprutils::Memory::CUniquePointer
