@@ -59,6 +59,13 @@ struct SVersionInfo {
 #define OPTIONAL
 #define HANDLE void*
 
+// C ABI is needed to prevent symbol mangling, but we don't actually need C compatibility,
+// so we ignore this warning about return types that are potentially incompatible with C.
+#ifdef __clang__
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
+#endif
+
 class IHyprLayout;
 class CWindow;
 class IHyprWindowDecoration;
@@ -70,7 +77,7 @@ class CWindow;
     Methods marked with REQUIRED are required.
 */
 
-/* 
+/*
     called pre-plugin init.
     In case of a version mismatch, will eject the .so.
 
@@ -223,7 +230,7 @@ namespace HyprlandAPI {
 
         returns: true on success. False otherwise.
     */
-    APICALL bool addWindowDecoration(HANDLE handle, PHLWINDOW pWindow, std::unique_ptr<IHyprWindowDecoration> pDecoration);
+    APICALL bool addWindowDecoration(HANDLE handle, PHLWINDOW pWindow, UP<IHyprWindowDecoration> pDecoration);
 
     /*
         Removes a window decoration
@@ -236,8 +243,17 @@ namespace HyprlandAPI {
         Adds a keybind dispatcher.
 
         returns: true on success. False otherwise.
+
+        DEPRECATED: use addDispatcherV2
     */
-    APICALL bool addDispatcher(HANDLE handle, const std::string& name, std::function<void(std::string)> handler);
+    APICALL [[deprecated]] bool addDispatcher(HANDLE handle, const std::string& name, std::function<void(std::string)> handler);
+
+    /*
+        Adds a keybind dispatcher.
+
+        returns: true on success. False otherwise.
+    */
+    APICALL bool addDispatcherV2(HANDLE handle, const std::string& name, std::function<SDispatchResult(std::string)> handler);
 
     /*
         Removes a keybind dispatcher.
@@ -306,3 +322,7 @@ APICALL inline EXPORT const char* __hyprland_api_get_client_hash() {
     return GIT_COMMIT_HASH;
 }
 // NOLINTEND
+
+#ifdef __clang__
+#pragma clang diagnostic pop
+#endif
