@@ -9,19 +9,22 @@ class CEventLoopTimer;
 
 class CExtIdleNotification {
   public:
-    CExtIdleNotification(SP<CExtIdleNotificationV1> resource_, uint32_t timeoutMs);
+    CExtIdleNotification(SP<CExtIdleNotificationV1> resource_, uint32_t timeoutMs, bool obeyInhibitors);
     ~CExtIdleNotification();
 
     bool good();
     void onTimerFired();
     void onActivity();
 
-  private:
-    SP<CExtIdleNotificationV1> resource;
-    uint32_t                   timeoutMs = 0;
-    SP<CEventLoopTimer>        timer;
+    bool inhibitorsAreObeyed() const;
 
-    bool                       idled = false;
+  private:
+    SP<CExtIdleNotificationV1> m_resource;
+    uint32_t                   m_timeoutMs = 0;
+    SP<CEventLoopTimer>        m_timer;
+
+    bool                       m_idled          = false;
+    bool                       m_obeyInhibitors = false;
 
     void                       updateTimer();
 };
@@ -38,13 +41,13 @@ class CIdleNotifyProtocol : public IWaylandProtocol {
   private:
     void onManagerResourceDestroy(wl_resource* res);
     void destroyNotification(CExtIdleNotification* notif);
-    void onGetNotification(CExtIdleNotifierV1* pMgr, uint32_t id, uint32_t timeout, wl_resource* seat);
+    void onGetNotification(CExtIdleNotifierV1* pMgr, uint32_t id, uint32_t timeout, wl_resource* seat, bool obeyInhibitors);
 
     bool isInhibited = false;
 
     //
-    std::vector<UP<CExtIdleNotifierV1>>   m_vManagers;
-    std::vector<SP<CExtIdleNotification>> m_vNotifications;
+    std::vector<UP<CExtIdleNotifierV1>>   m_managers;
+    std::vector<SP<CExtIdleNotification>> m_notifications;
 
     friend class CExtIdleNotification;
 };
