@@ -10,13 +10,13 @@
 class CTitleTex {
   public:
     CTitleTex(PHLWINDOW pWindow, const Vector2D& bufferSize, const float monitorScale);
-    ~CTitleTex();
+    ~CTitleTex() = default;
 
-    SP<CTexture> tex;
-    std::string  szContent;
-    Vector2D     texSize;
+    SP<CTexture> m_texActive;
+    SP<CTexture> m_texInactive;
+    std::string  m_content;
 
-    PHLWINDOWREF pWindowOwner;
+    PHLWINDOWREF m_windowOwner;
 };
 
 void refreshGroupBarGradients();
@@ -24,7 +24,7 @@ void refreshGroupBarGradients();
 class CHyprGroupBarDecoration : public IHyprWindowDecoration {
   public:
     CHyprGroupBarDecoration(PHLWINDOW);
-    virtual ~CHyprGroupBarDecoration();
+    virtual ~CHyprGroupBarDecoration() = default;
 
     virtual SDecorationPositioningInfo getPositioningInfo();
 
@@ -47,16 +47,14 @@ class CHyprGroupBarDecoration : public IHyprWindowDecoration {
     virtual std::string                getDisplayName();
 
   private:
-    SBoxExtents               m_seExtents;
+    CBox                      m_assignedBox = {0};
 
-    CBox                      m_bAssignedBox = {0};
-
-    PHLWINDOWREF              m_pWindow;
+    PHLWINDOWREF              m_window;
 
     std::vector<PHLWINDOWREF> m_dwGroupMembers;
 
-    float                     m_fBarWidth;
-    float                     m_fBarHeight;
+    float                     m_barWidth;
+    float                     m_barHeight;
 
     CTitleTex*                textureFromTitle(const std::string&);
     void                      invalidateTextures();
@@ -71,5 +69,5 @@ class CHyprGroupBarDecoration : public IHyprWindowDecoration {
     struct STitleTexs {
         // STitleTexs*                            overriden = nullptr; // TODO: make shit shared in-group to decrease VRAM usage.
         std::vector<UP<CTitleTex>> titleTexs;
-    } m_sTitleTexs;
+    } m_titleTexs;
 };
