@@ -16,9 +16,8 @@ class CTexPassElement : public IPassElement {
         int                   round         = 0;
         float                 roundingPower = 2.0f;
         bool                  flipEndFrame  = false;
-        SP<CSyncTimeline>     syncTimeline;
-        int64_t               syncPoint = 0;
         std::optional<Mat3x3> replaceProjection;
+        CBox                  clipBox;
     };
 
     CTexPassElement(const SRenderData& data);
@@ -36,5 +35,5 @@ class CTexPassElement : public IPassElement {
     }
 
   private:
-    SRenderData data;
+    SRenderData m_data;
 };
